==> gammaray_2.4.0.orig.tar.xz: gammaray-2.4.0/core/tools/modelinspector/safetyfilterproxymodel.cpp <==
/*
  safetyfilterproxymodel.cpp

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "safetyfilterproxymodel.h"

using namespace GammaRay;

SafetyFilterProxyModel::SafetyFilterProxyModel(QObject* parent): QIdentityProxyModel(parent)
{
}

SafetyFilterProxyModel::~SafetyFilterProxyModel()
{
}

QVariant SafetyFilterProxyModel::data(const QModelIndex& proxyIndex, int role) const
{
    if (sourceModel() && sourceModel()->inherits("QQmlListModel")) {
        // data on anything not in roleNames() crashes
        if (!sourceModel()->roleNames().contains(role)) {
            if (role == Qt::DisplayRole)
              return QLatin1String("CRASH GUARD");
            return QVariant();
        }
    }

    return QAbstractProxyModel::data(proxyIndex, role);
}

==> gammaray_2.5.1.orig.tar.xz: gammaray-2.5.1/core/tools/modelinspector/safetyfilterproxymodel.cpp <==
/*
  safetyfilterproxymodel.cpp

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "safetyfilterproxymodel.h"

using namespace GammaRay;

SafetyFilterProxyModel::SafetyFilterProxyModel(QObject *parent)
    : QIdentityProxyModel(parent)
{
}

SafetyFilterProxyModel::~SafetyFilterProxyModel()
{
}

QVariant SafetyFilterProxyModel::data(const QModelIndex &proxyIndex, int role) const
{
    if (sourceModel() && sourceModel()->inherits("QQmlListModel")) {
        // data on anything not in roleNames() crashes
        if (!sourceModel()->roleNames().contains(role))
            return QVariant();
    }

    return QAbstractProxyModel::data(proxyIndex, role);
}
